==> igniteui-react-core-18.2.0-beta.2.tgz: package/esm5/lib/AssigningCategoryStyleEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { AssigningSeriesShapeStyleEventArgsBaseDescriptionMetadata } from "./AssigningSeriesShapeStyleEventArgsBaseDescriptionMetadata";
import { AssigningCategoryStyleEventArgsDescription } from "./AssigningCategoryStyleEventArgsDescription";
/**
 * @hidden
 */
var AssigningCategoryStyleEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(AssigningCategoryStyleEventArgsDescriptionMetadata, _super);
    function AssigningCategoryStyleEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    AssigningCategoryStyleEventArgsDescriptionMetadata.b = function (a) {
        if (AssigningCategoryStyleEventArgsDescriptionMetadata.a == null) {
            AssigningCategoryStyleEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            AssigningCategoryStyleEventArgsDescriptionMetadata.c(AssigningCategoryStyleEventArgsDescriptionMetadata.a);
        }
        if (a.k(AssigningCategoryStyleEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.ab(AssigningCategoryStyleEventArgsDescriptionMetadata.a);
    };
    AssigningCategoryStyleEventArgsDescriptionMetadata.c = function (a) {
        AssigningSeriesShapeStyleEventArgsBaseDescriptionMetadata.c(a);
    };
    AssigningCategoryStyleEventArgsDescriptionMetadata.d = function (a) {
        AssigningCategoryStyleEventArgsDescriptionMetadata.b(a);
        a.ad("AssigningCategoryStyleEventArgs", function () { return new AssigningCategoryStyleEventArgsDescription(); });
        a.ac("AssigningCategoryStyleEventArgs", AssigningCategoryStyleEventArgsDescriptionMetadata.a);
    };
    AssigningCategoryStyleEventArgsDescriptionMetadata.$t = markType(AssigningCategoryStyleEventArgsDescriptionMetadata, 'AssigningCategoryStyleEventArgsDescriptionMetadata');
    AssigningCategoryStyleEventArgsDescriptionMetadata.a = null;
    return AssigningCategoryStyleEventArgsDescriptionMetadata;
}(Base));
export { AssigningCategoryStyleEventArgsDescriptionMetadata };

==> igniteui-react-core-18.7.5-beta.2.tgz: package/esm5/lib/AssigningCategoryStyleEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { AssigningSeriesShapeStyleEventArgsBaseDescriptionMetadata } from "./AssigningSeriesShapeStyleEventArgsBaseDescriptionMetadata";
import { AssigningCategoryStyleEventArgsDescription } from "./AssigningCategoryStyleEventArgsDescription";
/**
 * @hidden
 */
var AssigningCategoryStyleEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(AssigningCategoryStyleEventArgsDescriptionMetadata, _super);
    function AssigningCategoryStyleEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    AssigningCategoryStyleEventArgsDescriptionMetadata.b = function (a) {
        if (AssigningCategoryStyleEventArgsDescriptionMetadata.a == null) {
            AssigningCategoryStyleEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            AssigningCategoryStyleEventArgsDescriptionMetadata.c(AssigningCategoryStyleEventArgsDescriptionMetadata.a);
        }
        if (a.k(AssigningCategoryStyleEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.ac(AssigningCategoryStyleEventArgsDescriptionMetadata.a);
    };
    AssigningCategoryStyleEventArgsDescriptionMetadata.c = function (a) {
        AssigningSeriesShapeStyleEventArgsBaseDescriptionMetadata.c(a);
    };
    AssigningCategoryStyleEventArgsDescriptionMetadata.d = function (a) {
        AssigningCategoryStyleEventArgsDescriptionMetadata.b(a);
        a.ae("AssigningCategoryStyleEventArgs", function () { return new AssigningCategoryStyleEventArgsDescription(); });
        a.ad("AssigningCategoryStyleEventArgs", AssigningCategoryStyleEventArgsDescriptionMetadata.a);
    };
    AssigningCategoryStyleEventArgsDescriptionMetadata.$t = markType(AssigningCategoryStyleEventArgsDescriptionMetadata, 'AssigningCategoryStyleEventArgsDescriptionMetadata');
    AssigningCategoryStyleEventArgsDescriptionMetadata.a = null;
    return AssigningCategoryStyleEventArgsDescriptionMetadata;
}(Base));
export { AssigningCategoryStyleEventArgsDescriptionMetadata };
